from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool
import time
import models


class CssBackgroundPlugIn(CMSPluginBase):
    model = models.CssBackground
    name = 'CSS Background'
    render_template = 'css_background.html'
    raw_id_fields = ('image',)
    fieldsets = (
        (None, {
            'fields': ('bg_type', 'image', ('r', 'g', 'b', 'a')),
        }),
    )

    def render(self, context, instance, placeholder):
        context.update({
            'instance': instance,
            'time': '-'.join([
                str(instance.id),
                str(instance.image.id),
                repr(time.time()).replace('.', '_')]),
        })
        return context

plugin_pool.register_plugin(CssBackgroundPlugIn)



from django.db import models
from cms.models import CMSPlugin
from filer.fields.image import FilerImageField


class CssBackground(CMSPlugin):

    BG_CHOICES = (
        ('image', 'image'),
        ('rgb', 'rgb'),
        ('rgba', 'rgba'),
    )

    bg_type = models.CharField(
        max_length=5, choices=BG_CHOICES, default='image')
    image = FilerImageField(
        null=True, blank=True,
        default=None, verbose_name='image')
    r = models.IntegerField(default=0)
    g = models.IntegerField(default=0)
    b = models.IntegerField(default=0)
    a = models.IntegerField(default=0)

    class Meta:
        verbose_name = "css background"

    def clean(self):
        from django.core.exceptions import ValidationError
        if self.bg_type == 'image' and not self.image:
            raise ValidationError('You must select an image')
        elif self.bg_type == 'rgb' and (
                not self.r or not self.g or not self.b):
            raise ValidationError('You must provide "r", "g" and "b" values')
        elif self.bg_type == 'rgba' and (
                not self.r or not self.g or not self.b):
            raise ValidationError(
                'You must provide "r", "g", "b" and "a" values')

    @property
    def css_background(self):

        if self.bg_type == 'image':

            return ''.join([
                'background-image: url(',
                self.image.url,
                ');'])

        elif self.bg_type == 'rgb':

            return ''.join([
                'background-color: rgb(',
                str(self.r), ',',
                str(self.g), ',',
                str(self.b), ');'])

        elif self.bg_type == 'rgba':

            return ''.join([
                'background-color: rgb(',
                str(self.r), ',',
                str(self.g), ',',
                str(self.b), ',',
                str(self.a), ');'])

        return ''

    def __unicode__(self):
        if self.bg_type == 'image':
            return self.image.label
        elif self.bg_type == 'rgb':
            return u'rgb: %s-%s-%s' % (self.r, self.g, self.b)
        elif self.bg_type == 'rgba':
            return u'rgba: %s-%s-%s-%s' % (self.r, self.g, self.b, self.a)



# -*- coding: utf-8 -*-
from setuptools import setup, find_packages


try:
    import pypandoc
    description = pypandoc.convert('README.md', 'rst')
except (IOError, ImportError):
    with open('README.md', 'rb') as f:
        description = f.read()


setup(
    name='djangocms-css-background',
    version='1.0.1',
    license='MIT',
    description='A django-cms plugin which allow you to edit css background image or color from the edit mode',
    long_description=description,
    author='Steeve',
    author_email='mo0ofier@gmail.com',
    include_package_data=True,
    url='https://github.com/WnP/djangocms-css-background',
    packages=find_packages(),
    install_requires=[
        'django-cms>=3.0.5',
        'djangocms-placeholder-attr>=1.0.2',
    ],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
    ],
    zip_safe=False,
)

## Installation by Mauricio Aizga - @MaoAiz
